==> zio-aws-databasemigration_2.13-5.17.123.1-sources.jar: zio/aws/databasemigration/model/Certificate.scala <==
package zio.aws.databasemigration.model
import zio.aws.databasemigration.model.primitives.{
  IntegerOptional,
  CertificateWallet,
  TStamp
}
import java.time.Instant
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import java.lang.Integer
import scala.jdk.CollectionConverters._
final case class Certificate(
    certificateIdentifier: Option[String] = None,
    certificateCreationDate: Option[TStamp] = None,
    certificatePem: Option[String] = None,
    certificateWallet: Option[CertificateWallet] = None,
    certificateArn: Option[String] = None,
    certificateOwner: Option[String] = None,
    validFromDate: Option[TStamp] = None,
    validToDate: Option[TStamp] = None,
    signingAlgorithm: Option[String] = None,
    keyLength: Option[IntegerOptional] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.databasemigration.model.Certificate = {
    import Certificate.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.databasemigration.model.Certificate
      .builder()
      .optionallyWith(
        certificateIdentifier.map(value => value: java.lang.String)
      )(_.certificateIdentifier)
      .optionallyWith(
        certificateCreationDate.map(value => TStamp.unwrap(value): Instant)
      )(_.certificateCreationDate)
      .optionallyWith(certificatePem.map(value => value: java.lang.String))(
        _.certificatePem
      )
      .optionallyWith(
        certificateWallet.map(value =>
          software.amazon.awssdk.core.SdkBytes.fromByteArrayUnsafe(
            value.toArray[Byte]
          )
        )
      )(_.certificateWallet)
      .optionallyWith(certificateArn.map(value => value: java.lang.String))(
        _.certificateArn
      )
      .optionallyWith(certificateOwner.map(value => value: java.lang.String))(
        _.certificateOwner
      )
      .optionallyWith(
        validFromDate.map(value => TStamp.unwrap(value): Instant)
      )(_.validFromDate)
      .optionallyWith(validToDate.map(value => TStamp.unwrap(value): Instant))(
        _.validToDate
      )
      .optionallyWith(signingAlgorithm.map(value => value: java.lang.String))(
        _.signingAlgorithm
      )
      .optionallyWith(
        keyLength.map(value => IntegerOptional.unwrap(value): Integer)
      )(_.keyLength)
      .build()
  }
  def asReadOnly: zio.aws.databasemigration.model.Certificate.ReadOnly =
    zio.aws.databasemigration.model.Certificate.wrap(buildAwsValue())
}
object Certificate {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.databasemigration.model.Certificate
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.databasemigration.model.Certificate =
      zio.aws.databasemigration.model.Certificate(
        certificateIdentifier.map(value => value),
        certificateCreationDate.map(value => value),
        certificatePem.map(value => value),
        certificateWallet.map(value => value),
        certificateArn.map(value => value),
        certificateOwner.map(value => value),
        validFromDate.map(value => value),
        validToDate.map(value => value),
        signingAlgorithm.map(value => value),
        keyLength.map(value => value)
      )
    def certificateIdentifier: Option[String]
    def certificateCreationDate: Option[TStamp]
    def certificatePem: Option[String]
    def certificateWallet: Option[CertificateWallet]
    def certificateArn: Option[String]
    def certificateOwner: Option[String]
    def validFromDate: Option[TStamp]
    def validToDate: Option[TStamp]
    def signingAlgorithm: Option[String]
    def keyLength: Option[IntegerOptional]
    def getCertificateIdentifier: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("certificateIdentifier", certificateIdentifier)
    def getCertificateCreationDate: ZIO[Any, AwsError, TStamp] = AwsError
      .unwrapOptionField("certificateCreationDate", certificateCreationDate)
    def getCertificatePem: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("certificatePem", certificatePem)
    def getCertificateWallet: ZIO[Any, AwsError, CertificateWallet] =
      AwsError.unwrapOptionField("certificateWallet", certificateWallet)
    def getCertificateArn: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("certificateArn", certificateArn)
    def getCertificateOwner: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("certificateOwner", certificateOwner)
    def getValidFromDate: ZIO[Any, AwsError, TStamp] =
      AwsError.unwrapOptionField("validFromDate", validFromDate)
    def getValidToDate: ZIO[Any, AwsError, TStamp] =
      AwsError.unwrapOptionField("validToDate", validToDate)
    def getSigningAlgorithm: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("signingAlgorithm", signingAlgorithm)
    def getKeyLength: ZIO[Any, AwsError, IntegerOptional] =
      AwsError.unwrapOptionField("keyLength", keyLength)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.databasemigration.model.Certificate
  ) extends zio.aws.databasemigration.model.Certificate.ReadOnly {
    override val certificateIdentifier: Option[String] =
      scala.Option(impl.certificateIdentifier()).map(value => value: String)
    override val certificateCreationDate: Option[TStamp] = scala
      .Option(impl.certificateCreationDate())
      .map(value => zio.aws.databasemigration.model.primitives.TStamp(value))
    override val certificatePem: Option[String] =
      scala.Option(impl.certificatePem()).map(value => value: String)
    override val certificateWallet: Option[CertificateWallet] = scala
      .Option(impl.certificateWallet())
      .map(value =>
        zio.aws.databasemigration.model.primitives
          .CertificateWallet(zio.Chunk.fromArray(value.asByteArrayUnsafe()))
      )
    override val certificateArn: Option[String] =
      scala.Option(impl.certificateArn()).map(value => value: String)
    override val certificateOwner: Option[String] =
      scala.Option(impl.certificateOwner()).map(value => value: String)
    override val validFromDate: Option[TStamp] = scala
      .Option(impl.validFromDate())
      .map(value => zio.aws.databasemigration.model.primitives.TStamp(value))
    override val validToDate: Option[TStamp] = scala
      .Option(impl.validToDate())
      .map(value => zio.aws.databasemigration.model.primitives.TStamp(value))
    override val signingAlgorithm: Option[String] =
      scala.Option(impl.signingAlgorithm()).map(value => value: String)
    override val keyLength: Option[IntegerOptional] = scala
      .Option(impl.keyLength())
      .map(value =>
        zio.aws.databasemigration.model.primitives.IntegerOptional(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.databasemigration.model.Certificate
  ): zio.aws.databasemigration.model.Certificate.ReadOnly = new Wrapper(impl)
}

==> zio-aws-databasemigration_2.13-5.17.151.2-sources.jar: zio/aws/databasemigration/model/Certificate.scala <==
package zio.aws.databasemigration.model
import zio.aws.databasemigration.model.primitives.{
  IntegerOptional,
  CertificateWallet,
  TStamp
}
import java.time.Instant
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import java.lang.Integer
import scala.jdk.CollectionConverters._
final case class Certificate(
    certificateIdentifier: Option[String] = None,
    certificateCreationDate: Option[TStamp] = None,
    certificatePem: Option[String] = None,
    certificateWallet: Option[CertificateWallet] = None,
    certificateArn: Option[String] = None,
    certificateOwner: Option[String] = None,
    validFromDate: Option[TStamp] = None,
    validToDate: Option[TStamp] = None,
    signingAlgorithm: Option[String] = None,
    keyLength: Option[IntegerOptional] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.databasemigration.model.Certificate = {
    import Certificate.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.databasemigration.model.Certificate
      .builder()
      .optionallyWith(
        certificateIdentifier.map(value => value: java.lang.String)
      )(_.certificateIdentifier)
      .optionallyWith(
        certificateCreationDate.map(value => TStamp.unwrap(value): Instant)
      )(_.certificateCreationDate)
      .optionallyWith(certificatePem.map(value => value: java.lang.String))(
        _.certificatePem
      )
      .optionallyWith(
        certificateWallet.map(value =>
          software.amazon.awssdk.core.SdkBytes.fromByteArrayUnsafe(
            value.toArray[Byte]
          )
        )
      )(_.certificateWallet)
      .optionallyWith(certificateArn.map(value => value: java.lang.String))(
        _.certificateArn
      )
      .optionallyWith(certificateOwner.map(value => value: java.lang.String))(
        _.certificateOwner
      )
      .optionallyWith(
        validFromDate.map(value => TStamp.unwrap(value): Instant)
      )(_.validFromDate)
      .optionallyWith(validToDate.map(value => TStamp.unwrap(value): Instant))(
        _.validToDate
      )
      .optionallyWith(signingAlgorithm.map(value => value: java.lang.String))(
        _.signingAlgorithm
      )
      .optionallyWith(keyLength.map(value => value: Integer))(_.keyLength)
      .build()
  }
  def asReadOnly: zio.aws.databasemigration.model.Certificate.ReadOnly =
    zio.aws.databasemigration.model.Certificate.wrap(buildAwsValue())
}
object Certificate {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.databasemigration.model.Certificate
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.databasemigration.model.Certificate =
      zio.aws.databasemigration.model.Certificate(
        certificateIdentifier.map(value => value),
        certificateCreationDate.map(value => value),
        certificatePem.map(value => value),
        certificateWallet.map(value => value),
        certificateArn.map(value => value),
        certificateOwner.map(value => value),
        validFromDate.map(value => value),
        validToDate.map(value => value),
        signingAlgorithm.map(value => value),
        keyLength.map(value => value)
      )
    def certificateIdentifier: Option[String]
    def certificateCreationDate: Option[TStamp]
    def certificatePem: Option[String]
    def certificateWallet: Option[CertificateWallet]
    def certificateArn: Option[String]
    def certificateOwner: Option[String]
    def validFromDate: Option[TStamp]
    def validToDate: Option[TStamp]
    def signingAlgorithm: Option[String]
    def keyLength: Option[IntegerOptional]
    def getCertificateIdentifier: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("certificateIdentifier", certificateIdentifier)
    def getCertificateCreationDate: ZIO[Any, AwsError, TStamp] = AwsError
      .unwrapOptionField("certificateCreationDate", certificateCreationDate)
    def getCertificatePem: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("certificatePem", certificatePem)
    def getCertificateWallet: ZIO[Any, AwsError, CertificateWallet] =
      AwsError.unwrapOptionField("certificateWallet", certificateWallet)
    def getCertificateArn: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("certificateArn", certificateArn)
    def getCertificateOwner: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("certificateOwner", certificateOwner)
    def getValidFromDate: ZIO[Any, AwsError, TStamp] =
      AwsError.unwrapOptionField("validFromDate", validFromDate)
    def getValidToDate: ZIO[Any, AwsError, TStamp] =
      AwsError.unwrapOptionField("validToDate", validToDate)
    def getSigningAlgorithm: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("signingAlgorithm", signingAlgorithm)
    def getKeyLength: ZIO[Any, AwsError, IntegerOptional] =
      AwsError.unwrapOptionField("keyLength", keyLength)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.databasemigration.model.Certificate
  ) extends zio.aws.databasemigration.model.Certificate.ReadOnly {
    override val certificateIdentifier: Option[String] =
      scala.Option(impl.certificateIdentifier()).map(value => value: String)
    override val certificateCreationDate: Option[TStamp] = scala
      .Option(impl.certificateCreationDate())
      .map(value => zio.aws.databasemigration.model.primitives.TStamp(value))
    override val certificatePem: Option[String] =
      scala.Option(impl.certificatePem()).map(value => value: String)
    override val certificateWallet: Option[CertificateWallet] = scala
      .Option(impl.certificateWallet())
      .map(value =>
        zio.aws.databasemigration.model.primitives
          .CertificateWallet(zio.Chunk.fromArray(value.asByteArrayUnsafe()))
      )
    override val certificateArn: Option[String] =
      scala.Option(impl.certificateArn()).map(value => value: String)
    override val certificateOwner: Option[String] =
      scala.Option(impl.certificateOwner()).map(value => value: String)
    override val validFromDate: Option[TStamp] = scala
      .Option(impl.validFromDate())
      .map(value => zio.aws.databasemigration.model.primitives.TStamp(value))
    override val validToDate: Option[TStamp] = scala
      .Option(impl.validToDate())
      .map(value => zio.aws.databasemigration.model.primitives.TStamp(value))
    override val signingAlgorithm: Option[String] =
      scala.Option(impl.signingAlgorithm()).map(value => value: String)
    override val keyLength: Option[IntegerOptional] =
      scala.Option(impl.keyLength()).map(value => value: IntegerOptional)
  }
  def wrap(
      impl: software.amazon.awssdk.services.databasemigration.model.Certificate
  ): zio.aws.databasemigration.model.Certificate.ReadOnly = new Wrapper(impl)
}
